Documentation
¶
Index ¶
- Variables
- func CommentAnchor(path, side string, line int) string
- func IsCommentNotFound(err error) bool
- type Comment
- type CommentStore
- type DB
- func (d *DB) AddComment(slug, branch, path, side string, line int, body string) (Comment, error)
- func (d *DB) Close() error
- func (d *DB) DeleteComment(slug, id string) error
- func (d *DB) GetComment(slug, id string) (Comment, error)
- func (d *DB) ListComments(slug, branch string) ([]Comment, error)
- func (d *DB) SetCommentResolved(slug, id string, resolved bool, body string) (Comment, error)
- func (d *DB) UpdateCommentBody(slug, id, body string) (Comment, error)
- type NopCommentStore
- func (NopCommentStore) AddComment(string, string, string, string, int, string) (Comment, error)
- func (NopCommentStore) DeleteComment(string, string) error
- func (NopCommentStore) GetComment(string, string) (Comment, error)
- func (NopCommentStore) ListComments(string, string) ([]Comment, error)
- func (NopCommentStore) SetCommentResolved(string, string, bool, string) (Comment, error)
- func (NopCommentStore) UpdateCommentBody(string, string, string) (Comment, error)
Constants ¶
This section is empty.
Variables ¶
var ErrCommentNotFound = errors.New("comment not found")
Functions ¶
func CommentAnchor ¶
func IsCommentNotFound ¶
Types ¶
type Comment ¶
type CommentStore ¶
type CommentStore interface {
AddComment(slug, branch, path, side string, line int, body string) (Comment, error)
DeleteComment(slug, id string) error
GetComment(slug, id string) (Comment, error)
ListComments(slug, branch string) ([]Comment, error)
SetCommentResolved(slug, id string, resolved bool, body string) (Comment, error)
UpdateCommentBody(slug, id, body string) (Comment, error)
}
type DB ¶
type DB struct {
// contains filtered or unexported fields
}
func (*DB) AddComment ¶
func (*DB) DeleteComment ¶
func (*DB) SetCommentResolved ¶
type NopCommentStore ¶
type NopCommentStore struct{}
func (NopCommentStore) AddComment ¶
func (NopCommentStore) DeleteComment ¶
func (NopCommentStore) DeleteComment(string, string) error
func (NopCommentStore) GetComment ¶
func (NopCommentStore) GetComment(string, string) (Comment, error)
func (NopCommentStore) ListComments ¶
func (NopCommentStore) ListComments(string, string) ([]Comment, error)
func (NopCommentStore) SetCommentResolved ¶
func (NopCommentStore) UpdateCommentBody ¶
Click to show internal directories.
Click to hide internal directories.